@@ -85,7 +85,7 @@ void messageUpdate()
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
-    a.setWindowIcon(QIcon("/usr/share/pixmaps/mx-conky.png"));
+    a.setWindowIcon(QIcon::fromTheme("mx-conky"));
 
     QTranslator qtTran;
     qtTran.load(QString("qt_") + QLocale::system().name());
